@@ -1,4 +1,4 @@
-## Copyright (C) 2012, 2013 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2012-2014 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -16,15 +16,15 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {[@var{p}, @var{objf}, @var{cvg}, @var{outp}] =} nonlin_min (@var{f}, @var{pin})
 ## @deftypefnx {Function File} {[@var{p}, @var{objf}, @var{cvg}, @var{outp}] =} nonlin_min (@var{f}, @var{pin}, @var{settings})
+## Frontend for nonlinear minimization of a scalar objective function.
 ##
-## Frontend for constrained nonlinear minimization of a scalar objective
-## function. The functions supplied by the user have a minimal
-## interface; any additionally needed constants can be supplied by
-## wrapping the user functions into anonymous functions.
+## The functions supplied by the user have a minimal interface; any
+## additionally needed constants can be supplied by wrapping the user
+## functions into anonymous functions.
 ##
 ## The following description applies to usage with vector-based
 ## parameter handling. Differences in usage for structure-based
-## parameter handling will be explained in a separate section below.
+## parameter handling will be explained separately.
 ##
 ## @var{f}: objective function. It gets a column vector of real
 ## parameters as argument. In gradient determination, this function may
@@ -34,302 +34,46 @@
 ## @var{pin}: real column vector of initial parameters.
 ##
 ## @var{settings}: structure whose fields stand for optional settings
-## referred to below. The fields can be set by @code{optimset()} with
-## Octave versions 3.3.55 or greater; with older Octave versions, the
-## fields must be set directly as structure-fields in the correct case.
+## referred to below. The fields can be set by @code{optimset()}.
 ##
 ## The returned values are the column vector of final parameters
 ## @var{p}, the final value of the objective function @var{objf}, an
 ## integer @var{cvg} indicating if and how optimization succeeded or
 ## failed, and a structure @var{outp} with additional information,
-## curently with only one field: @var{niter}, the number of iterations.
-## @var{cvg} is greater than zero for success and less than or equal to
-## zero for failure; its possible values depend on the used backend and
-## currently can be @code{0} (maximum number of iterations exceeded),
-## @code{1} (fixed number of iterations completed, e.g. in stochastic
-## optimizers), @code{2} (parameter change less than specified precision
-## in two consecutive iterations), @code{3} (improvement in objective
-## function less than specified), or @code{-4} (algorithm got stuck).
+## curently with possible fields: @code{niter}, the number of
+## iterations, @code{nobjf}, the number of objective function calls
+## (indirect calls by gradient function not counted), @code{lambda}, the
+## lambda of constraints at the result, and @code{user_interaction},
+## information on user stops (see settings). The backend may define
+## additional fields. @var{cvg} is greater than zero for success and
+## less than or equal to zero for failure; its possible values depend on
+## the used backend and currently can be @code{0} (maximum number of
+## iterations exceeded), @code{1} (success without further specification
+## of criteria), @code{2} (parameter change less than specified
+## precision in two consecutive iterations), @code{3} (improvement in
+## objective function less than specified), @code{-1} (algorithm aborted
+## by a user function), or @code{-4} (algorithm got stuck).
 ##
-## @var{settings}:
+## @c The following block will be cut out in the package info file.
+## @c BEGIN_CUT_TEXINFO
 ##
-## @code{Algorithm}: String specifying the backend. Currently available
-## are @code{"lm_feasible"} (default) and @code{"siman"}. They are
-## described in separate sections below.
+## For settings, type @code{optim_doc ("nonlin_min")}.
 ##
-## @code{objf_grad}: Function computing the gradient of the objective
-## function with respect to the parameters. Will be called with the
-## column vector of parameters and an informational structure as
-## arguments. The structure has the fields @code{f}: value of objective
-## function for current parameters, @code{fixed}: logical vector
-## indicating which parameters are not optimized, so these partial
-## derivatives need not be computed and can be set to zero,
-## @code{diffp}, @code{diff_onesided}, @code{lbound}, @code{ubound}:
-## identical to the user settings of this name, @code{plabels}:
-## 1-dimensional cell-array of column-cell-arrays, each column with
-## labels for all parameters, the first column contains the numerical
-## indices of the parameters. The default gradient function will call
-## the objective function with the second argument set with fields
-## @code{f}: as the @code{f} passed to the gradient function,
-## @code{plabels}: cell-array of 1x1 cell-arrays with the entries of the
-## column-cell-arrays of @code{plabels} as passed to the jacobian
-## function corresponding to current parameter, @code{side}: @code{0}
-## for one-sided interval, @code{1} or @code{2}, respectively, for the
-## sides of a two-sided interval, and @code{parallel}: logical scalar
-## indicating parallel computation of partial derivatives.
+## For desription of structure-based parameter handling, type
+## @code{optim_doc ("parameter structures")}.
 ##
-## @code{objf_hessian}: Function computing the Hessian of the objective
-## function with respect to the parameters. The default is backend
-## specific. Will be called with the column vector of parameters as
-## argument.
+## For description of individual backends (currently only one), type
+## @code{optim_doc ("scalar optimization")} and choose the backend in
+## the menu.
 ##
-## @code{diffp}: column vector of fractional intervals (doubled for
-## central intervals) supposed to be used by gradient functions
-## performing finite differencing. Default: @code{.001 * ones (size
-## (parameters))}. The default gradient function will use these as
-## absolute intervals for parameters with value zero.
-##
-## @code{diff_onesided}: logical column vector indicating that one-sided
-## intervals should be used by gradient functions performing finite
-## differencing. Default: @code{false (size (parameters))}.
-##
-## @code{complex_step_derivative_objf},
-## @code{complex_step_derivative_inequc},
-## @code{complex_step_derivative_equc}: logical scalars, default: false.
-## Estimate gradient of objective function, general inequality
-## constraints, and general equality constraints, respectively, with
-## complex step derivative approximation. Use only if you know that your
-## objective function, function of general inequality constraints, or
-## function of general equality constraints, respectively, is suitable
-## for this. No user function for the respective gradient must be
-## specified.
-##
-## @code{cstep}: scalar step size for complex step derivative
-## approximation. Default: 1e-20.
-##
-## @code{parallel_local}: logical scalar, default: false. Estimate
-## gradient of objective function and of constraints in parallel
-## processes. Works for default finite difference gradient function and
-## for complex step derivatives. Due to overhead, a speed advantage can
-## only be expected if objective function or constraint functions are
-## time consuming enough.
-##
-## @code{fixed}: logical column vector indicating which parameters
-## should not be optimized, but kept to their inital value. Fixing is
-## done independently of the backend, but the backend may choose to fix
-## additional parameters under certain conditions.
-##
-## @code{lbound}, @code{ubound}: column vectors of lower and upper
-## bounds for parameters. Default: @code{-Inf} and @code{+Inf},
-## respectively. The bounds are non-strict, i.e. parameters are allowed
-## to be exactly equal to a bound. The default gradient function will
-## respect bounds (but no further inequality constraints) in finite
-## differencing.
-##
-## @code{inequc}: Further inequality constraints. Cell-array containing
-## up to four entries, two entries for linear inequality constraints
-## and/or one or two entries for general inequality constraints. Either
-## linear or general constraints may be the first entries, but the two
-## entries for linear constraints must be adjacent and, if two entries
-## are given for general constraints, they also must be adjacent. The
-## two entries for linear constraints are a matrix (say @code{m}) and a
-## vector (say @code{v}), specifying linear inequality constraints of
-## the form @code{m.' * parameters + v >= 0}. The first entry for
-## general constraints must be a differentiable column-vector valued
-## function (say @code{h}), specifying general inequality constraints of
-## the form @code{h (p[, idx]) >= 0}; @code{p} is the column vector of
-## optimized parameters and the optional argument @code{idx} is a
-## logical index. @code{h} has to return the values of all constraints
-## if @code{idx} is not given. It may choose to return only the indexed
-## constraints if @code{idx} is given (so computation of the other
-## constraints can be spared); in this case, the additional setting
-## @code{f_inequc_idx} has to be set to @code{true}. In gradient
-## determination, this function may be called with an informational
-## third argument, whose content depends on the function for gradient
-## determination. If a second entry for general inequality constraints
-## is given, it must be a function computing the jacobian of the
-## constraints with respect to the parameters. For this function, the
-## description of @code{dfdp} above applies, with 2 exceptions: 1) it is
-## called with 3 arguments since it has an additional argument
-## @code{idx}, a logical index, at second position, indicating which
-## rows of the jacobian must be returned (if the function chooses to
-## return only indexed rows, the additional setting @code{df_inequc_idx}
-## has to be set to @code{true}). 2) the default jacobian function calls
-## @code{h} with 3 arguments, since the argument @code{idx} is also
-## supplied. Note that specifying linear constraints as general
-## constraints will generally waste performance, even if further,
-## non-linear, general constraints are also specified.
-##
-## @code{equc}: Equality constraints. Specified the same way as
-## inequality constraints (see @code{inequc}). The respective additional
-## settings are named @code{f_equc_idx} and @code{df_equc_idx}.
-##
-## @code{cpiv}: Function for complementary pivoting, usable in
-## algorithms for constraints. Default: @ cpiv_bard. Only the default
-## function is supplied with the package.
-##
-## @code{TolFun}: Minimum fractional improvement in objective function
-## in an iteration (termination criterium). Default: .0001.
-##
-## @code{MaxIter}: Maximum number of iterations (termination criterium).
-## Default: backend-specific.
-##
-## @code{fract_prec}: Column Vector, minimum fractional change of
-## parameters in an iteration (termination criterium if violated in two
-## consecutive iterations). Default: backend-specific.
-##
-## @code{max_fract_change}: Column Vector, enforced maximum fractional
-## change in parameters in an iteration. Default: backend-specific.
-##
-## @code{Display}: String indicating the degree of verbosity. Default:
-## @code{"off"}. Possible values are currently @code{"off"} (no
-## messages) and @code{"iter"} (some messages after each iteration).
-## Support of this setting and its exact interpretation are
-## backend-specific.
-##
-## @code{debug}: Logical scalar, default: @code{false}. Will be passed
-## to the backend, which might print debugging information if true.
-##
-## Structure-based parameter handling
-##
-## The setting @code{param_order} is a cell-array with names of the
-## optimized parameters. If not given, and initial parameters are a
-## structure, all parameters in the structure are optimized. If initial
-## parameters are a structure, it is an error if @code{param_order} is
-## not given and there are any non-structure-based configuration items
-## or functions.
-##
-## The initial parameters @var{pin} can be given as a structure
-## containing at least all fields named in @code{param_order}. In this
-## case the returned parameters @var{p} will also be a structure.
-##
-## Each user-supplied function can be called with the argument
-## containing the current parameters being a structure instead of a
-## column vector. For this, a corresponding setting must be set to
-## @code{true}: @code{objf_pstruct} (objective function),
-## @code{grad_objf_pstruct} (gradient of objective function),
-## @code{hessian_objf_pstruct} (hessian of objective function),
-## @code{f_inequc_pstruct} (general inequality constraints),
-## @code{df_inequc_pstruct} (jacobian of general inequality
-## constraints), @code{f_equc_pstruct} (general equality constraints),
-## and @code{df_equc_pstruct} (jacobian of general equality
-## constraints). If a gradient (jacobian) function is configured in such
-## a way, it must return the entries (columns) of the gradient
-## (jacobian) as fields of a structure under the respective parameter
-## names. If the hessian function is configured in such a way, it must
-## return a structure (say @code{h}) with fields e.g. as
-## @code{h.a.b = value} for @code{value} being the 2nd partial derivative
-## with respect to @code{a} and @code{b}. There is no need to also
-## specify the field @code{h.b.a} in this example.
-##
-## Similarly, for specifying linear constraints, instead of the matrix
-## (called @code{m} above), a structure containing the rows of the
-## matrix in fields under the respective parameter names can be given.
-## In this case, rows containing only zeros need not be given.
-##
-## The vector-based settings @code{lbound}, @code{ubound},
-## @code{fixed}, @code{diffp}, @code{diff_onesided}, @code{fract_prec},
-## and @code{max_fract_change} can be replaced by the setting
-## @code{param_config}. It is a structure that can contain fields named
-## in @code{param_order}. For each such field, there may be subfields
-## with the same names as the above vector-based settings, but
-## containing a scalar value for the respective parameter. If
-## @code{param_config} is specified, none of the above
-## vector/matrix-based settings may be used.
-##
-## Additionally, named parameters are allowed to be non-scalar real
-## arrays. In this case, their dimensions are given by the setting
-## @code{param_dims}, a cell-array of dimension vectors, each containing
-## at least two dimensions; if not given, dimensions are taken from the
-## initial parameters, if these are given in a structure. Any
-## vector-based settings or not structure-based linear constraints then
-## must correspond to an order of parameters with all parameters
-## reshaped to vectors and concatenated in the user-given order of
-## parameter names. Structure-based settings or structure-based initial
-## parameters must contain arrays with dimensions reshapable to those of
-## the respective parameters.
-##
-## Description of backends
-##
-## "lm_feasible"
-##
-## A Levenberg/Marquardt-like optimizer, attempting to honour
-## constraints throughout the course of optimization. This means that
-## the initial parameters must not violate constraints (to find an
-## initial feasible set of parameters, e.g. Octaves @code{sqp} can be
-## used, by specifying an objective function which is constant or which
-## returns the quadratic distance to the initial values). If the
-## constraints need only be honoured in the result of the optimization,
-## Octaves @code{sqp} may be preferable. The Hessian is either supplied
-## by the user or is approximated by the BFGS algorithm.
-##
-## Returned value @var{cvg} will be @code{2} or @code{3} for success and
-## @code{0} or @code{-4} for failure (see above for meaning).
-##
-## Backend-specific defaults are: @code{MaxIter}: 20, @code{fract_prec}:
-## @code{zeros (size (parameters))}, @code{max_fract_change}: @code{Inf}
-## for all parameters.
-##
-## Interpretation of @code{Display}: if set to @code{"iter"}, currently
-## only information on applying @code{max_fract_change} is printed.
-##
-## "siman"
-##
-## A simulated annealing (stochastic) optimizer, changing all parameters
-## at once in a single step, so being suitable for non-bound
-## constraints.
-##
-## No gradient or hessian of the objective function is used. The
-## settings @code{MaxIter}, @code{fract_prec}, @code{TolFun}, and
-## @code{max_fract_change} are not honoured.
-##
-## Accepts the additional settings @code{T_init} (initial temperature,
-## default 0.01), @code{T_min} (final temperature, default 1.0e-5),
-## @code{mu_T} (factor of temperature decrease, default 1.005),
-## @code{iters_fixed_T} (iterations within one temperature step, default
-## 10), @code{max_rand_step} (column vector or structure-based
-## configuration of maximum random steps for each parameter, default
-## 0.005 * @var{pin}), @code{stoch_regain_constr} (if @code{true},
-## regain constraints after a random step, otherwise take new random
-## value until constraints are met, default false), @code{trace_steps}
-## (set field @code{trace} of @var{outp} with a matrix with a row for
-## each step, first column iteration number, second column repeat number
-## within iteration, third column value of objective function, rest
-## columns parameter values, default false), and @code{siman_log} (set
-## field @code{log} of @var{outp} with a matrix with a row for each
-## iteration, first column temperature, second column value of objective
-## function, rest columns numbers of tries with decrease, no decrease
-## but accepted, and no decrease and rejected.
-##
-## Steps with increase @code{diff} of objective function are accepted if
-## @code{rand (1) < exp (- diff / T)}, where @code{T} is the temperature
-## of the current iteration.
-##
-## If regaining of constraints failed, optimization will be aborted and
-## returned value of @var{cvg} will be @code{0}. Otherwise, @var{cvg}
-## will be @code{1}.
-##
-## Interpretation of @code{Display}: if set to @code{"iter"}, an
-## informational line is printed after each iteration.
+## @c END_CUT_TEXINFO
 ##
 ## @end deftypefn
 
-## disabled PKG_ADD: __all_opts__ ("nonlin_min");
+## PKG_ADD: __all_opts__ ("nonlin_min");
 
 function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 
-  if (compare_versions (version (), "3.3.55", "<"))
-    ## optimset mechanism was fixed for option names with underscores
-    ## sometime in 3.3.54+, if I remember right
-    optimget = @ __optimget__;
-  endif
-
-  if (compare_versions (version (), "3.2.4", "<="))
-    ## For bug #31484; but Octave 3.6... shows bug #36288 due to this
-    ## workaround. Octave 3.7... seems to be all right.
-    __dfdp__ = @ __dfdp__;
-  endif
-
   ## some scalar defaults; some defaults are backend specific, so
   ## lacking elements in respective constructed vectors will be set to
   ## NA here in the frontend
@@ -352,9 +96,10 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 		  "ubound", [], ...
 		  "objf_grad", [], ...
 		  "objf_hessian", [], ...
+                  "inverse_hessian", false, ...
 		  "cpiv", @ cpiv_bard, ...
 		  "max_fract_change", [], ...
-		  "fract_prec", [], ...
+		  "fract_prec", [], ... # vector, TolX is a scalar
 		  "diffp", [], ...
 		  "diff_onesided", [], ...
 		  "complex_step_derivative_objf", false, ...
@@ -369,11 +114,13 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
                   "f_equc_idx", false, ...
                   "df_equc_idx", false, ...
 		  "TolFun", stol_default, ...
+                  "TolX", [], ...
 		  "MaxIter", [], ...
 		  "Display", "off", ...
 		  "Algorithm", "lm_feasible", ...
                   "parallel_local", false, ... # Matlabs UseParallel
                                 # works differently
+                  "user_interaction", {}, ...
 		  "T_init", .01, ...
 		  "T_min", 1.0e-5, ...
 		  "mu_T", 1.005, ...
@@ -382,7 +129,11 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 		  "stoch_regain_constr", false, ...
                   "trace_steps", false, ...
                   "siman_log", false, ...
-		  "debug", false);
+		  "debug", false, ...
+                  "FunValCheck", "off", ...
+                  "save_state", "", ...
+                  "recover_state", "", ...
+                  "octave_sqp_tolerance", []);
     return;
   endif
 
@@ -406,6 +157,9 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 
   #### processing of settings and consistency checks
 
+  backend = optimget (settings, "Algorithm", "lm_feasible");
+  backend = map_matlab_algorithm_names (backend);
+  [backend, path_bounds] = map_backend (backend);
   pconf = optimget (settings, "param_config");
   pord = optimget (settings, "param_order");
   pdims = optimget (settings, "param_dims");
@@ -437,6 +191,10 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
       optimget (settings, "complex_step_derivative_inequc", false);
   do_cstep_equc = optimget (settings, "complex_step_derivative_equc", ...
 			    false);
+  if (! iscell (user_interaction = ...
+                optimget (settings, "user_interaction", {})))
+    user_interaction = {user_interaction};
+  endif
   max_rand_step = optimget (settings, "max_rand_step");
 
   any_vector_conf = ! (isempty (lbound) && isempty (ubound) && ...
@@ -784,6 +542,17 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     error ("some lower bounds larger than upper bounds");
   endif
 
+  ## pass bounds only if the backend respects bounds even during the
+  ## course of optimization
+  if (path_bounds)
+    jac_lbound = lbound;
+    jac_ubound = ubound;
+  else
+    jac_lbound = - Infvec;
+    jac_ubound = Infvec;
+  endif
+
+
   #### consider whether initial parameters and functions are based on
   #### parameter structures or parameter vectors; wrappers for call to
   #### default function for jacobians
@@ -812,7 +581,6 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 	  f (cell2struct (num2cell (p), pord, 1), varargin{:});
     endif
   endif
-  f_pin = f (pin);
 
   ## gradient of objective function
   if (isempty (dfdp))
@@ -968,11 +736,11 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
       s_diff_onesided = cell2struct ...
 	  (cellfun (@ reshape, mat2cell (diff_onesided, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_orig_lbound = cell2struct ...
-	  (cellfun (@ reshape, mat2cell (lbound, ppartidx), ...
+      s_jac_lbound = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (jac_lbound, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_orig_ubound = cell2struct ...
-	  (cellfun (@ reshape, mat2cell (ubound, ppartidx), ...
+      s_jac_ubound = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (jac_ubound, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
       s_plabels = cell2struct ...
 	  (num2cell ...
@@ -989,8 +757,8 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     else
       s_diffp = cell2struct (num2cell (diffp), pord, 1);
       s_diff_onesided = cell2struct (num2cell (diff_onesided), pord, 1);
-      s_orig_lbound = cell2struct (num2cell (lbound), pord, 1);
-      s_orig_ubound = cell2struct (num2cell (ubound), pord, 1);
+      s_jac_lbound = cell2struct (num2cell (jac_lbound), pord, 1);
+      s_jac_ubound = cell2struct (num2cell (jac_ubound), pord, 1);
       s_plabels = cell2struct (num2cell (plabels, 2), pord, 1);
       s_orig_fixed = cell2struct (num2cell (fixed), pord, 1);
     endif
@@ -1061,7 +829,8 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   endif
 
   #### collect remaining settings
-  parallel_local = optimget (settings, "parallel_local", false);
+  parallel_local = hook.parallel_local = ...
+      __optimget_parallel_local__ (settings, false);
   hook.MaxIter = optimget (settings, "MaxIter");
   if (ischar (hook.cpiv = optimget (settings, "cpiv", @ cpiv_bard)))
     hook.cpiv = str2func (hook.cpiv);
@@ -1078,13 +847,15 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
       optimget (settings, "trace_steps", false);
   hook.siman_log = ...
       optimget (settings, "siman_log", false);
-  backend = optimget (settings, "Algorithm", "lm_feasible");
-  backend = map_matlab_algorithm_names (backend);
-  backend = map_backend (backend);
+  hook.save_state = optimget (settings, "save_state", "");
+  hook.recover_state = optimget (settings, "recover_state", "");
+  hook.octave_sqp_tolerance = ...
+      optimget (settings, "octave_sqp_tolerance", []);
+  hook.inverse_hessian = optimget (settings, "inverse_hessian", false);
+  hook.TolX = optimget (settings, "TolX", []);
+  hook.FunValCheck = optimget (settings, "FunValCheck", "off");
 
   #### handle fixing of parameters
-  orig_lbound = lbound;
-  orig_ubound = ubound;
   orig_fixed = fixed;
   if (all (fixed))
     error ("no free parameters");
@@ -1151,8 +922,8 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   if (dfdp_pstruct)
     dfdp = @ (p, hook) ...
 	dfdp (p, cell2fields ...
-	      ({s_diffp, s_diff_onesided, s_orig_lbound, ...
-		s_orig_ubound, s_plabels, ...
+	      ({s_diffp, s_diff_onesided, s_jac_lbound, ...
+		s_jac_ubound, s_plabels, ...
 		cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
 			    1, s_orig_fixed), ...
                 cstep, parallel_local}, ...
@@ -1162,7 +933,7 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   else
     dfdp = @ (p, hook) ...
 	dfdp (p, cell2fields ...
-	      ({diffp, diff_onesided, orig_lbound, orig_ubound, ...
+	      ({diffp, diff_onesided, jac_lbound, jac_ubound, ...
 		plabels, assign(orig_fixed, nonfixed, hook.fixed), ...
 		cstep, parallel_local}, ...
 	       {"diffp", "diff_onesided", "lbound", "ubound", ...
@@ -1174,8 +945,8 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   if (df_inequc_pstruct)
     df_gencstr = @ (p, func, idx, hook) ...
 	df_gencstr (p, func, idx, cell2fields ...
-		    ({s_diffp, s_diff_onesided, s_orig_lbound, ...
-		      s_orig_ubound, s_plabels, ...
+		    ({s_diffp, s_diff_onesided, s_jac_lbound, ...
+		      s_jac_ubound, s_plabels, ...
 		      cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
 				  1, s_orig_fixed), ...
                       cstep, parallel_local}, ...
@@ -1185,8 +956,8 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   else
     df_gencstr = @ (p, func, idx, hook) ...
 	df_gencstr (p, func, idx, cell2fields ...
-		    ({diffp, diff_onesided, orig_lbound, ...
-		      orig_ubound, plabels, ...
+		    ({diffp, diff_onesided, jac_lbound, ...
+		      jac_ubound, plabels, ...
 		      assign(orig_fixed, nonfixed, hook.fixed), ...
                       cstep, parallel_local}, ...
 		     {"diffp", "diff_onesided", "lbound", "ubound", ...
@@ -1198,8 +969,8 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   if (df_equc_pstruct)
     df_genecstr = @ (p, func, idx, hook) ...
 	df_genecstr (p, func, idx, cell2fields ...
-		     ({s_diffp, s_diff_onesided, s_orig_lbound, ...
-		       s_orig_ubound, s_plabels, ...
+		     ({s_diffp, s_diff_onesided, s_jac_lbound, ...
+		       s_jac_ubound, s_plabels, ...
 		       cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
 				   1, s_orig_fixed), ...
                        cstep, parallel_local}, ...
@@ -1209,8 +980,8 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   else
     df_genecstr = @ (p, func, idx, hook) ...
 	df_genecstr (p, func, idx, cell2fields ...
-		     ({diffp, diff_onesided, orig_lbound, ...
-		       orig_ubound, plabels, ...
+		     ({diffp, diff_onesided, jac_lbound, ...
+		       jac_ubound, plabels, ...
 		       assign(orig_fixed, nonfixed, hook.fixed), ...
                        cstep, parallel_local}, ...
 		      {"diffp", "diff_onesided", "lbound", "ubound", ...
@@ -1327,15 +1098,13 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## passed function for complementary pivoting
   ## hook.cpiv = cpiv; # set before
 
-  ## passed value of objective function for initial parameters
-  hook.f_pin = f_pin;
-
   ## passed options
   hook.max_fract_change = max_fract_change;
   hook.fract_prec = fract_prec;
   ## hook.TolFun = ; # set before
   ## hook.MaxIter = ; # set before
   hook.fixed = fixed;
+  hook.user_interaction = user_interaction;
   hook.max_rand_step = max_rand_step;
 
   #### call backend
@@ -1361,7 +1130,7 @@ function backend = map_matlab_algorithm_names (backend)
 
 endfunction
 
-function backend = map_backend (backend)
+function [backend, path_bounds] = map_backend (backend)
 
   switch (backend)
       ##    case "sqp_infeasible"
@@ -1370,8 +1139,16 @@ function backend = map_backend (backend)
       ##      backend = "__sqp__";
     case "lm_feasible"
       backend = "__lm_feasible__";
+      path_bounds = true;
+    case "octave_sqp"
+      backend = "__octave_sqp_wrapper__";
+      path_bounds = false;
     case "siman"
       backend = "__siman__";
+      path_bounds = true;
+    case "d2_min"
+      backend = "__d2_min__";
+      path_bounds = false;
     otherwise
       error ("no backend implemented for algorithm '%s'", backend);
   endswitch
@@ -1405,18 +1182,6 @@ function m = hessian_struct2mat (s, pord)
 
 endfunction
 
-function ret = __optimget__ (s, name, default)
-
-  if (isfield (s, name))
-    ret = s.(name);
-  elseif (nargin > 2)
-    ret = default;
-  else
-    ret = [];
-  endif
-
-endfunction
-
 function ret = apply_idx_if_given  (ret, varargin)
 
   if (nargin > 1)
