@@ -57,6 +57,9 @@ function ret = optim_problems ()
   %% .dfdp: handle of internally defined function for jacobian of
   %% objective function or 'model function', respectively.
   %%
+  %% .hessian: (not for curve fitting) handle of internally defined
+  %% function for hessian of objective function. Not always supplied.
+  %%
   %% .init_p: initial parameters, column vector
   %%
   %% possibly .init_p_b: two column matrix of ranges to choose initial
@@ -122,7 +125,8 @@ function ret = optim_problems ()
   %% numbered from 201 to 395 and may appear here under the fields
   %% .curve, .general, or .zero.
   %%
-  %% .general.schittkowski_281: 10 parameters, unconstrained.
+  %% .general.schittkowski_281: 10 parameters, unconstrained. Hessian
+  %% supplied.
   %%
   %% .general.schittkowski_289: 30 parameters, unconstrained.
   %%
@@ -154,6 +158,10 @@ function ret = optim_problems ()
   %% fminunc). The result still varies widely (without much changes in
   %% objective function) with changes of starting values. Maybe not a
   %% very good test problem, no well defined minimum ...
+  %%
+  %% .general.rosenbrock: 2D Rosenbrock function. Hessian supplied. The
+  %% parameters a and b of the Rosenbrock function are set to 1 and 100,
+  %% respectively.
 
   %% needed for some anonymous functions
   if (exist ('ifelse') ~= 5)
@@ -399,6 +407,8 @@ function ret = optim_problems ()
 
   ret.general.schittkowski_281.dfdp = ...
       @ (p) schittkowski_281_dfdp (p);
+  ret.general.schittkowski_281.hessian = ...
+      @ (p) schittkowski_281_hessian (p);
   ret.general.schittkowski_281.init_p = zeros (10, 1);
   ret.general.schittkowski_281.result.p = ones (10, 1); % 'theoretically'
   ret.general.schittkowski_281.result.obj = 0; % 'theoretically'
@@ -435,6 +445,26 @@ function ret = optim_problems ()
   ret.general.schittkowski_289.equc.general = [];
   ret.general.schittkowski_289.f = @ (p) 1 - exp (- sum (p .^ 2) / 60);
 
+  ret.general.rosenbrock.f = @ (p) (1 - p(1))^2 + 100 * (p(2) - ...
+                                                         p(1)^2)^2;
+  ret.general.rosenbrock.dfdp = @ (p) ...
+      [- 2 * (1 - p(1)) - 400 * p(1) * (p(2) - p(1)^2); ...
+       200 * (p(2) - p(1)^2)];
+  ret.general.rosenbrock.hessian = @ (p) ...
+      [2 + 1200 * p(1)^2 - 400 * p(2), ...
+       - 400 * p(1); ...
+       - 400 * p(1), ...
+       200];
+  ret.general.rosenbrock.init_p = [-10; -10]; # arbitrary, take what you want
+  ret.general.rosenbrock.result.p = [1; 1]; # exact solution
+  ret.general.rosenbrock.result.obj = 0; # exact solution
+  ret.general.rosenbrock.strict_inequc.bounds = [];
+  ret.general.rosenbrock.strict_inequc.linear = [];
+  ret.general.rosenbrock.strict_inequc.general = [];
+  ret.general.rosenbrock.non_strict_inequc.bounds = [];
+  ret.general.rosenbrock.non_strict_inequc.linear = [];
+  ret.general.rosenbrock.non_strict_inequc.general = [];
+
   ret.curve.schittkowski_327.dfdp = ...
       @ (x, p) [1 + exp(-p(2) * (x - 8)), ...
 		(p(1) + .49) * (8 - x) .* exp (-p(2) * (x - 8))];
@@ -853,6 +883,20 @@ function ret = optim_problems ()
 
     ret = 2 * ((1:10).') .^ 3 .* (p - 1) * tp;
 
+  function ret = schittkowski_281_hessian (p)
+
+    k3 = ((1:10).^3).';
+
+    p = p(:);
+
+    p_1 = p - 1;
+
+    s_k_p = sum (k3 .* p_1.^2);
+
+    ret = - 8 / 9 * s_k_p^(- 5 / 3) * ...
+        (k3 * k3.') .* (p_1 * p_1.') + ...
+        diag (2 / 3 * s_k_p^(- 2 / 3) * k3);
+
   function state = fixed_step_rk4 (t, x0, step, f)
 
     %% minimalistic fourth order ODE-solver, as said to be a popular one
