@@ -287,10 +287,10 @@ function prt = __dfdp__ (p, func, hook)
         for (id = 1 : n_childs)
           if (child_data(id, 1))
             pclose (child_data(id, 1));
-            if (child_data(id, 2))
-              system (sprintf ("kill -9 %i", child_data(id, 2)));
-              waitpid (child_data(id, 2));
-            endif
+          endif
+          if (child_data(id, 2))
+            kill (child_data(id, 2), 9);
+            waitpid (child_data(id, 2));
           endif
         endfor
 
