@@ -35,9 +35,6 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
   ## passed values of constraints for initial parameters
   pin_cstr = hook.pin_cstr;
 
-  ## passed return value of f for initial parameters
-  f_pin = hook.f_pin;
-
   ## passed function for gradient of objective function
   grad_f = hook.dfdp;
 
@@ -47,6 +44,9 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
     A = eye (n);
   else
     user_hessian = true;
+    if (hook.inverse_hessian)
+      error ("this backend can't handle inverse hessians");
+    endif
   endif
 
   ## passed function for complementary pivoting
@@ -67,6 +67,7 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
   add_pprec(pprec > 0) = sqrt (eps);
   ##
   verbose = strcmp (hook.Display, "iter");
+  user_interaction = hook.user_interaction;
 
   ## some useful variables derived from passed variables
   n_lcstr = size (vc, 1);
@@ -108,8 +109,9 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
 
   ## set up for iterations
   p = pbest = pin;
-  vf = fbest = f_pin;
+  vf = fbest = f (pin);
   iter = 0;
+  nobjf = 1;
   done = false;
   ll = 1;
   ltab = [.1, 1, 1e2, 1e4, 1e6];
@@ -118,6 +120,18 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
   c_act = false (n, 1);
   dca = zeros (n, 0);
 
+  if (([stop, outp.user_interaction] = ...
+       __do_user_interaction__ (user_interaction, p,
+                                struct ("iteration", 0,
+                                        "fval", vf),
+                                "init")))
+    p_res = p;
+    outp.niter = 0;
+    objf = vf;
+    cvg = -1;
+    return;
+  endif
+
   while (! done)
 
     iter++;
@@ -469,6 +483,7 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
         if (! isreal (vf_chg = f (p_chg)))
           error ("objective function not real");
         endif
+        nobjf++;
         if (vf_chg < fbest)
           pbest = p_chg;
           fbest = vf_chg;
@@ -487,6 +502,18 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
 
     ll = l;
 
+    if (([stop, outp.user_interaction] = ...
+         __do_user_interaction__ (user_interaction, p,
+                                  struct ("iteration", iter,
+                                          "fval", vf),
+                                  "iter")))
+      p_res = p;
+      outp.niter = iter;
+      objf = vf;
+      cvg = -1;
+      return;
+    endif
+
     aprec = pprec .* (abs (pbest) + add_pprec);
     if (skipped)
       cvg = 2;
@@ -511,5 +538,14 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
   p_res = pbest;
   objf = fbest;
   outp.niter = iter;
+  outp.nobjf = nobjf;
+
+  if (([stop, outp.user_interaction] = ...
+       __do_user_interaction__ (user_interaction, p_res,
+                                struct ("iteration", iter,
+                                        "fval", objf),
+                                "done")))
+    cvg = -1;
+  endif
 
 endfunction
