@@ -1,4 +1,4 @@
-## Copyright (C) 2011-2013 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2011-2014 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -34,16 +34,8 @@
 ## interface for both uses may be confusing otherwise, also the optimset
 ## options only partially overlap.
 
-## disabled PKG_ADD: __all_opts__ ("__residmin_stat__");
-
 function ret = __residmin_stat__ (f, pfin, settings, hook)
 
-  if (compare_versions (version (), "3.3.55", "<"))
-    ## optimset mechanism was fixed for option names with underscores
-    ## sometime in 3.3.54+, if I remember right
-    optimget = @ __optimget__;
-  endif
-
   ## scalar defaults
   diffp_default = .001;
   cstep_default = 1e-20;
@@ -336,7 +328,7 @@ function ret = __residmin_stat__ (f, pfin, settings, hook)
     if (any (size (residuals) != size (obs = hook.observations)))
       error ("dimensions of observations and values of model function must match");
     endif
-    f = @ (p) f (p) - obs;
+    f = @ (varargin) f (varargin{:}) - obs;
     residuals -= obs;
   endif
 
@@ -346,7 +338,6 @@ function ret = __residmin_stat__ (f, pfin, settings, hook)
       if (do_cstep)
 	dfdp = @ (p, hook) jacobs (p, f, hook);
       else
-	__dfdp__ = @ __dfdp__; # for bug #31484 (Octave <= 3.2.4)
 	dfdp = @ (p, hook) __dfdp__ (p, f, hook);
       endif
     endif
@@ -470,6 +461,10 @@ function ret = __residmin_stat__ (f, pfin, settings, hook)
   ## it is up to the end --- since other computations might need it in
   ## this form --- and supplemented with values corresponding to fixed
   ## parameters (mostly NA, probably) not until then.
+  ##
+  ## The jacobian backend is the only backend which has the whole
+  ## parameter vector available (including fixed elements), possibly
+  ## handling fixing internally (e.g. by omitting computation).
 
   nonfixed = ! fixed;
 
@@ -487,7 +482,7 @@ function ret = __residmin_stat__ (f, pfin, settings, hook)
     ## jacobian of model function
     if (! isempty (dfdp))
       dfdp = @ (p, hook) ...
-	  dfdp (assign (pfin, nonfixed, p), hook)(:, nonfixed);
+	  dfdp (assign (orig_p, nonfixed, p), hook)(:, nonfixed);
     endif
     
   endif
@@ -607,15 +602,3 @@ function lval = assign (lval, lidx, rval)
   lval(lidx) = rval;
 
 endfunction
-
-function ret = __optimget__ (s, name, default)
-
-  if (isfield (s, name))
-    ret = s.(name);
-  elseif (nargin > 2)
-    ret = default;
-  else
-    ret = [];
-  endif
-
-endfunction
