@@ -5,16 +5,20 @@
 ## @deftypefn {Function File} {[@var{p}, @var{s}] =} wpolyfit (@var{x}, @var{y}, @var{dy}, @var{n})
 ## Return the coefficients of a polynomial @var{p}(@var{x}) of degree
 ## @var{n} that minimizes
-## @iftex
-## @tex
-## $$
-## \sum_{i=1}^N (p(x_i) - y_i)^2
-## $$
-## @end tex
-## @end iftex
-## @ifinfo
-## @code{sumsq (p(x(i)) - y(i))},
-## @end ifinfo
+## @c ########################################################
+## @c These lines must be written without space at start to work around
+## @c a bug in html generation.
+##@iftex
+##@tex
+##$$
+##\sum_{i=1}^N (p(x_i) - y_i)^2
+##$$
+##@end tex
+##@end iftex
+##@ifnottex
+##@code{sumsq (p(x(i)) - y(i))},
+##@end ifnottex
+## @c ########################################################
 ## to best fit the data in the least squares sense.  The standard error
 ## on the observations @var{y} if present are given in @var{dy}.
 ##
@@ -70,7 +74,7 @@
 ## @var{y} from the returned model use
 ## @code{y = polyval(p, (x-mu(1))/mu(2)}
 ##
-## @deftypefnx {Function File} wpolyfit (...)
+## @deftypefnx {Function File} {} wpolyfit (...)
 ##
 ## If no output arguments are requested, then wpolyfit plots the data,
 ## the fitted line and polynomials defining the standard error range.
@@ -83,7 +87,7 @@
 ## wpolyfit(x,y,dy,2);
 ## @end example
 ##
-## @deftypefnx {Function File} wpolyfit (..., 'origin')
+## @deftypefnx {Function File} {} wpolyfit (..., 'origin')
 ##
 ## If 'origin' is specified, then the fitted polynomial will go through
 ## the origin.  This is generally ill-advised.  Use with caution.
@@ -91,8 +95,14 @@
 ## Hocking, RR (2003). Methods and Applications of Linear Models.
 ## New Jersey: John Wiley and Sons, Inc.
 ##
+## @c Will be cut out in optims info file and replaced with the same
+## @c refernces explicitely there, since references to core Octave
+## @c functions are not automatically transformed from here to there.
+## @c BEGIN_CUT_TEXINFO
+## @seealso{polyfit}
+## @c END_CUT_TEXINFO
+## @seealso{polyconf}
 ## @end deftypefn
-## @seealso{polyfit,polyconf}
 
 function [p_out, s, mu] = wpolyfit (varargin)
 
